Crate glyphr

Crate glyphr 

Glyphr

This library focus is not to be the fastest, but one of the most beautiful in the embedded world.

Macros

generate_font
Macro used to generate a font with data direcly in the code

Structs

BulkCallbacks
Callback-backed render target for per-glyph bulk writes.
Callbacks
Callback-backed render target.
Font
Font metadata and glyph table.
Glyph
Single glyph data.
Glyphr
Main renderer struct.
RenderConfig
Configuration for text rendering.
SdfConfig
Configuration for SDF rendering (only used with SDF fonts).
TextAlign
Text alignment options.

Enums

AlignH
Horizontal alignment.
AlignV
Vertical alignment.
BitmapFormat
Defines how glyph bitmaps are stored.
GlyphrError