Glyphr
This library focus is not to be the fastest, but one of the most beautiful in the embedded world.
Macros
- generate_
font - Macro used to generate a font with data direcly in the code
Structs
- Bulk
Callbacks - Callback-backed render target for per-glyph bulk writes.
- Callbacks
- Callback-backed render target.
- Font
- Font metadata and glyph table.
- Glyph
- Single glyph data.
- Glyphr
- Main renderer struct.
- Render
Config - Configuration for text rendering.
- SdfConfig
- Configuration for SDF rendering (only used with SDF fonts).
- Text
Align - Text alignment options.
Enums
- AlignH
- Horizontal alignment.
- AlignV
- Vertical alignment.
- Bitmap
Format - Defines how glyph bitmaps are stored.
- Glyphr
Error